@@ -1,4 +1,4 @@
-/* $Id: cdkmatrix.c,v 1.18 2014/11/06 00:19:48 tom Exp $ */
+/* $Id: cdkmatrix.c,v 1.19 2016/12/04 15:22:16 tom Exp $ */
 
 #include <cdk_test.h>
 
@@ -27,7 +27,6 @@ int main (int argc, char **argv)
    CDKSCREEN *cdkScreen         = 0;
    CDKMATRIX *widget            = 0;
    CDKBUTTONBOX *buttonWidget   = 0;
-   WINDOW *cursesWindow         = 0;
    chtype *holder               = 0;
    char *buttons                = 0;
    char *CDK_WIDGET_COLOR       = 0;
@@ -150,11 +149,7 @@ int main (int argc, char **argv)
       }
    }
 
-   /* Start curses. */
-   cursesWindow = initscr ();
-
-   /* Create the CDK screen. */
-   cdkScreen = initCDKScreen (cursesWindow);
+   cdkScreen = initCDKScreen (NULL);
 
    /* Start color. */
    initCDKColor ();
