@@ -1,4 +1,4 @@
-/* $Id: cdkviewer.c,v 1.14 2014/11/05 10:37:52 tom Exp $ */
+/* $Id: cdkviewer.c,v 1.15 2016/12/04 15:22:16 tom Exp $ */
 
 #include <cdk_test.h>
 
@@ -26,7 +26,6 @@ int main (int argc, char **argv)
    /* *INDENT-EQLS* */
    CDKSCREEN *cdkScreen         = 0;
    CDKVIEWER *widget            = 0;
-   WINDOW *cursesWindow         = 0;
    char *filename               = 0;
    char *CDK_WIDGET_COLOR       = 0;
    char *temp                   = 0;
@@ -106,9 +105,7 @@ int main (int argc, char **argv)
       title = copyChar (tempTitle);
    }
 
-   /* Set up CDK. */
-   cursesWindow = initscr ();
-   cdkScreen = initCDKScreen (cursesWindow);
+   cdkScreen = initCDKScreen (NULL);
 
    /* Start color. */
    initCDKColor ();
