@@ -1,4 +1,4 @@
-/* $Id: scale_ex.c,v 1.10 2012/03/21 23:17:28 tom Exp $ */
+/* $Id: scale_ex.c,v 1.11 2016/12/04 15:22:16 tom Exp $ */
 
 #include <cdk_test.h>
 
@@ -14,7 +14,6 @@ int main (int argc, char **argv)
    /* *INDENT-EQLS* */
    CDKSCREEN *cdkscreen = 0;
    CDKSCALE *widget     = 0;
-   WINDOW *cursesWin    = 0;
    const char *title    = "<C>Select a value";
    const char *label    = "</5>Current value";
    char temp[256];
@@ -31,9 +30,7 @@ int main (int argc, char **argv)
    inc = CDKparamNumber2 (&params, 'i', 1);
    low = CDKparamNumber2 (&params, 'l', 0);
 
-   /* Set up CDK. */
-   cursesWin = initscr ();
-   cdkscreen = initCDKScreen (cursesWin);
+   cdkscreen = initCDKScreen (NULL);
 
    /* Start CDK Colors. */
    initCDKColor ();
